@@ -156,3 +156,17 @@ def check_batch_size(batch_size):
     assert batch_size >= get_world_size(), \
         (f"batch size can't be smaller than number of processes "
          f'({batch_size} < {get_world_size()})')
+
+
+def average_all(tensor):
+    """Return the average of `tensor` over all workers."""
+    require_init()
+    if not using_deepspeed:
+        return tensor
+
+    require_torch_distributed_init()
+    # We copy because modification happens in-place
+    averaged = tensor.detach().clone()
+    # We use `all_reduce` because it is better supported than `reduce`
+    torch.distributed.all_reduce(averaged, torch.distributed.ReduceOp.SUM)
+    return averaged / get_world_size()
